# -*- coding: utf-8 -*-
__author__ = 'Iacopo Spalletti'
__email__ = 'i.spalletti@nephila.it'
__version__ = '0.8.7'

default_app_config = 'djangocms_blog.apps.BlogAppConfig'
